/*
 * getopt.c
 *
 * By Ross Ridge
 * Public Domain
 * 
 * Members of the class getopt.
 *
 */

#include "mysc.h"
#include "getopt.h"

#ifdef CONFIG_SCCS_IDS
static char const sccs_id[] = "@(#) MySC getopt.c 1.6 98/01/06 08:24:21";
#endif

#ifdef CONFIG_TRAIDTIONAL_ARGS

inline int
getopt::is_optional(char c) {
	return c == '?' || c == '*';
}

inline int
getopt::is_required(char c) {
	return c == ':';
}

#else /* CONFIG_TRADITIONAL_ARGS */

inline int
getopt::is_optional(char c) {
	return 0;
}

inline int
getopt::is_required(char c) {
	return c == '?' || c == ':';
}

#endif /* CONFIG_TRADITIONAL_ARGS */

int
getopt::next() {
	if (cindex == NULL || *cindex == '\0') {
		if (index >= argc) {
			return END_OF_ARGUMENTS;
		}
		cindex = argv[index];
		if (cindex[0] != '-' || cindex[1] == '\0') {
			return END_OF_ARGUMENTS;
		}
		index++;
		if (cindex[1] == '-' && cindex[2] == '\0') {
			return END_OF_ARGUMENTS;
		}
		cindex++;
	}

	char c = *cindex++;
	char const *match = strchr(opts, c);
	
	if (c == '\0' || match == NULL) {
		if (opterr) {
			quit(-2, msgptr(43, "Unrecognized option '%c'.\n"), c);
		}
		arg = cindex - 1;
		return UNRECOGNIZED_OPTION;
	}

	char type = match[1];

	if (is_optional(type)) {
		if (*cindex == '\0') {
			arg = NULL;
		} else {
			arg = cindex;
		}
		cindex = NULL;
	} else if (is_required(type)) {
		if (*cindex == '\0') {
			if (index >= argc) {
				if (opterr) {
					quit(-2, msgptr(44, 
							"Option '%c' requires"
							" an argument."), c);
				}
				arg = cindex - 1;
				return MISSING_ARGUMENT;
			}
			arg = argv[index++];
		} else {
			arg = cindex;
		}
		cindex = NULL;
	} else {
		arg = NULL;
	}

	return c;
}

/* Local variables: */
/* mode: c++ */
/* End: */
