#
# Makefile
#
# By Ross Ridge
# Public Domain
#
# Makefile for compiling the MySC utilities under Unix.
#
# @(#) MySC mf-unix.mm 1.20 00/05/12 16:37:25
# @(#) MySC mf-inc.mm 1.10 98/06/06 16:27:53
#

EMACS = emacs
SHELL = /bin/sh

CC = gcc
CFLAGS = -Wall -W -O -Wpointer-arith -Wwrite-strings -Wmissing-prototypes\
         -Wconversion -Wcast-align -Wstrict-prototypes -Wnested-externs\
         -Winline -Wno-comment -x c++ -fno-omit-frame-pointer\
         -nostdinc++ -fno-rtti -fno-exceptions -fpermissive $(DEBUGF)
LFLAGS = 
LIBS =

CMDS = get delta admin prs what unget sact cdc rmdel sccsdiff
XCMDS = get.x delta.x admin.x prs.x what.x unget.x sact.x cdc.x rmdel.x sccsdiff.x

GETOBJS = get.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o sccsfile.o \
	sf-get.o sf-get2.o sf-get3.o sf-get4.o sf-bseqt.o sf-chkid.o pfile.o \
	pf-add.o
DELTAOBJS = delta.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o sccsfile.o \
	sf-delta.o sf-get.o sf-get3.o sf-bseqt.o sf-chkid.o sf-write.o \
	sf-add.o pfile.o pf-del.o pipe.o run.o l-split.o prompt.o
ADMINOBJS = admin.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o sccsfile.o \
	sf-admin.o sf-chkid.o sf-write.o sf-bseqt.o sf-add.o run.o l-split.o \
	prompt.o
PRSOBJS = prs.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o sccsfile.o \
	sf-prs.o sf-get.o sf-bseqt.o sf-chkid.o
WHATOBJS = what.o quit.o xalloc.o getopt.o msgdb.o
UNGETOBJS = unget.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o pfile.o \
	pf-del.o
SACTOBJS = sact.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o pfile.o
CDCOBJS = cdc.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o sccsfile.o \
	sf-cdc.o sf-write.o run.o l-split.o prompt.o
RMDELOBJS = rmdel.o quit.o xalloc.o mystring.o sccsname.o sid.o sccsdate.o \
	linebuf.o file.o split.o getopt.o fileiter.o msgdb.o sccsfile.o \
	sf-rmdel.o sf-write.o pfile.o
SCCSDIFFOBJS = sccsdiff.o quit.o xalloc.o mystring.o sccsname.o sid.o \
	sccsdate.o linebuf.o file.o split.o getopt.o fileiter.o msgdb.o \
	sccsfile.o sf-get.o sf-get3.o sf-get4.o sf-chkid.o sf-bseqt.o pipe.o
SRCS = admin.c cdc.c delta.c file.c fileiter.c get.c getopt.c l-split.c \
	linebuf.c msgdb.c mystring.c pf-add.c pf-del.c pfile.c pipe.c \
	prompt.c prs.c quit.c rmdel.c run.c sact.c sccsdate.c sccsdiff.c \
	sccsfile.c sccsname.c sf-add.c sf-admin.c sf-bseqt.c sf-cdc.c \
	sf-chkid.c sf-delta.c sf-get.c sf-get2.c sf-get3.c sf-get4.c \
	sf-prs.c sf-rmdel.c sf-write.c sid.c split.c unget.c what.c xalloc.c
XSRCS = $(XCMDS:.x=.cs)
INCLUDES = defaults.h file.h fileiter.h filelock.h getopt.h linebuf.h \
	list.h mysc.h mystring.h pfile.h pipe.h quit.h run.h sccsdate.h \
	sccsfile.h sccsname.h seqstate.h sf-chkmr.h sid.h sid_list.h stack.h \
	sysdep.h version.h xalloc.h msgdb.h fsync.c _chmod.c strstr.c list.c \
	sid_list.c sl-merge.c

.SUFFIXES: .x .cs .i

.c.o: 
	$(CC) $(CFLAGS) -c $<

.c.s:
	$(CC) $(CFLAGS) -S $<

.c.i:
	$(CC) $(CFLAGS) -E $< > $@

.cs.x:
	$(CC) $(CFLAGS) $(LFLAGS) -o $@ $< $(LIBS)

it: $(CMDS)

xgcc: $(XCMDS)

get: $(GETOBJS)
	$(CC) $(LFLAGS) -o get $(GETOBJS) $(LIBS)

delta: $(DELTAOBJS)
	$(CC) $(LFLAGS) -o delta $(DELTAOBJS) $(LIBS)

admin: $(ADMINOBJS)
	$(CC) $(LFLAGS) -o admin $(ADMINOBJS) $(LIBS)

prs: $(PRSOBJS)
	$(CC) $(LFLAGS) -o prs $(PRSOBJS) $(LIBS)

what: $(WHATOBJS)
	$(CC) $(LFLAGS) -o what $(WHATOBJS) $(LIBS)

unget: $(UNGETOBJS)
	$(CC) $(LFLAGS) -o unget $(UNGETOBJS) $(LIBS)

sact: $(SACTOBJS)
	$(CC) $(LFLAGS) -o sact $(SACTOBJS) $(LIBS)

cdc: $(CDCOBJS)
	$(CC) $(LFLAGS) -o cdc $(CDCOBJS) $(LIBS)

rmdel: $(RMDELOBJS)
	$(CC) $(LFLAGS) -o rmdel $(RMDELOBJS) $(LIBS)

sccsdiff: $(SCCSDIFFOBJS)
	$(CC) $(LFLAGS) -o sccsdiff $(SCCSDIFFOBJS) $(LIBS)


sl-test: sid.h sid.c sid_list.h sid_list.c
	$(CC) $(CFLAGS) $(LFLAGS) -DTEST -o sl-test sid_list.c

gtest:
	-rm -f test/[spx].passwd
	./admin -itest/passwd.1 test/s.passwd
	./get -e -g test/s.passwd
	cp test/passwd.2 passwd
	./delta -Y test/s.passwd
	./get -e -g test/s.passwd
	cp test/passwd.3 passwd
	./delta -Y test/s.passwd
	./get -e -g -x1.2 test/s.passwd
	cp test/passwd.4 passwd
	./delta -Y test/s.passwd
	./get -e -g test/s.passwd
	cp test/passwd.5 passwd
	./delta -Y test/s.passwd
	./get -e -g -r1.3 test/s.passwd
	cp test/passwd.6 passwd
	./delta -Y test/s.passwd
	./get -r1.1 -p test/s.passwd > test/passwd.m1
	./get -r1.2 -p test/s.passwd > test/passwd.m2
	./get -r1.3 -p test/s.passwd > test/passwd.m3
	./get -r1.4 -p test/s.passwd > test/passwd.m4
	./get -r1.5 -p test/s.passwd > test/passwd.m5
	./get -r1.3.1.1 -p test/s.passwd > test/passwd.m6

depend: $(SRCS) $(XSRCS) $(INCLUDES) config.h
	sed -e '/^# YOW.$$/p' -e '/^# YOW.$$/,$$d' Makefile > makefile.new
	gcc $(CFLAGS) -MM $(SRCS) $(XSRCS) | sed -e "s/\.cs\.o/.x/" -e "s/ :/:/" -e "s/ cf-[^.]*\.h//" >> makefile.new

clean:
	-rm -f $(CMDS) $(XCMDS) *.o
	-rm -f core mf.tmp

srcs: $(SRCS) $(INCLUDES)

## !DIST.
#
#.SUFFIXES: .mm .mak
#
#AWK=awk
#TAR=tar
#GET=get
#PRS=prs
#DELTA=delta
#
#TAG_FILES = $(SRCS) $(INCLUDES) mf-inc.mm mf-unix.mm mf-msdos.mm make-cs.mm \
#	conformance.mm readme.mm why.mm install.txt cf-solaris.h myscmsgs
#OTHER_DIST = README INSTALL CONFORMANCE \
#	mf-msdos.mak mf-unix.mak cf-solaris.h myscmsgs
#DIST_FILES = $(OTHER_DIST) $(SRCS) $(INCLUDES) $(XSRCS)
#
#DIST_REL=2.1.1
#
#tag-dist: s.Manifest
#	$(GET) -r $(DIST_REL) -e -g s.Manifest
#	$(PRS) -d ":M: :I:" -R $(TAG_FILES) | sort > Manifest
#	$(DELTA) -Y s.Manifest
#
#dist: dist.tar
#
#dist.tar: dist-tmp.stamp
#	rm -f dist.tar
#	cd dist-tmp; $(TAR) cf ../dist.tar release.h $(DIST_FILES) 
#
#dist.shar: dist.shar.01 dist.shar.02 dist.shar.03 dist.shar.04 dist.shar.05 dist.shar.06
#
#dist.shar.01 dist.shar.02 dist.shar.03 dist.shar.04 dist.shar.05 dist.shar.06: dist-tmp.stamp mkshar.sh
#	cd dist-tmp; $(SHELL) ../mkshar.sh ../dist.shar release.h $(DIST_FILES)
#
#dist-tmp.stamp: s.Manifest Makefile
#	rm -rf dist-tmp.stamp dist-tmp 
#	mkdir dist-tmp
#	cd dist-tmp; $(GET) -p -r $(DIST_REL) ../s.Manifest		    \
#		| $(AWK) '{ print "$(GET) -r " $$2 " ../SCCS/s." $$1 " &&"} \
#			  END { print ":" }'				    \
#		| $(SHELL)
#	$(PRS) -d '#define MYSC_RELEASE_NUMBER ":I:"' -r $(DIST_REL)	    \
#		s.Manifest > dist-tmp/release.h
#	> dist-tmp/config.h
#	cd dist-tmp; make -f ../Makefile makefile.new
#	cd dist-tmp; make -f makefile.new $(DIST_FILES)
#	rm dist-tmp/config.h
#	rm dist-tmp/makefile.new
#	rm -f dist-tmp/install.txt
#	rm dist-tmp/*.txt
#	chmod 444 dist-tmp/* 
#	touch dist-tmp.stamp
#
#.mm.mak:
#	$(MYMAC) $< mf.tmp
#	sed -e '/^# !DIST\.$$/,/^# YOW\.$$/s/^/#/' -e 's/^## YOW\.$$/# YOW./' mf.tmp > $@
#	rm mf.tmp
#
#mf: makefile.new
#	$(MAKE) -f makefile.new MAKEFILE=Makefile Makefile
#
#MAKEFILE = GNU-make-botch
#
#$(MAKEFILE): makefile.new mf-deps.mak
#	test -f Makefile && cp Makefile Makefile.bak
#	cat makefile.new mf-deps.mak > Makefile
#
#mf-deps.mak: $(SRCS) $(XSRCS) $(INCLUDES) lex.yy.c
#	gcc $(CFLAGS) -MM $(SRCS) $(XSRCS) lex.yy.c | sed -e "s/\.cs\.o/.x/" -e "s/ :/:/" -e "s/ cf-[^.]*\.h//" > mf-deps.mak
#	
#EMACS = emacs
#MYMAC = $(EMACS) -batch -l mymac -f mymac-batch-expand-files
#
#$(XSRCS): make-cs.tmp
#
#make-cs.tmp: make-cs.mm mf-inc.mm
#	$(MYMAC) make-cs.mm make-cs.tmp
#
#makefile.new: mf-unix.mm mf-inc.mm
#	$(MYMAC) mf-unix.mm makefile.new
#
#mf-msdos.mak: mf-msdos.mm mf-inc.mm
#mf-unix.mak: mf-unix.mm mf-unix.mm
#
#MSGDB = myscmsgs
#
#LEX = lex
#LEXFLAGS = 
#
#mupdate: mupdate.sh msgscan $(MSGDB) $(SRCS) $(INCLUDES)
#	bash mupdate.sh $(MSGDB) $(SRCS) $(INCLUDES)
#
#msgscan: lex.yy.o xalloc.o quit.o linebuf.o mystring.o msgdb.o
#	$(CC) $(LFLAGS) -o msgscan lex.yy.o xalloc.o quit.o \
#		linebuf.o mystring.o msgdb.o -ll
#
#lex.yy.o: lex.yy.c
#	$(CC) $(CFLAGS) -D__EXTERN_C__ -Wno-missing-braces -c lex.yy.c
#
#lex.yy.c: msgscan.l
#	$(LEX) $(LEXFLAGS) msgscan.l
#
#docs: readme.txt readme.html conformance.txt conformance.html
#
#MYMAC_DOC_EXPAND = \
#	cat INCFILE $< > expand.tmp && \
#	$(MYMAC) expand.tmp expand.tmp && \
#	sed -n -e '/^./,$$p' expand.tmp > $@ && \
#	rm -f expand.tmp
#
#MYMAC_DIR = $(HOME)/emacs
#
#%.html: %.mm $(MYMAC_DIR)/fmt-html.mm
#	$(MYMAC_DOC_EXPAND:INCFILE=$(MYMAC_DIR)/fmt-html.mm)
#
#%.txt: %.mm $(MYMAC_DIR)/fmt-txt.mm
#	$(MYMAC_DOC_EXPAND:INCFILE=$(MYMAC_DIR)/fmt-txt.mm)
#
#README: readme.txt
#	cp readme.txt README
#
#INSTALL: install.txt
#	cp install.txt INSTALL
#
#CONFORMANCE: conformance.txt
#	cp conformance.txt CONFORMANCE
#
#WHY: why.txt
#	cp why.txt WHY
#
#WEBDIR = $(HOME)/www/mysc
#WEBDOCS = readme.html why.html conformance.html install.txt
#
#$(WEBDIR)/%.html: %.html
#	rm -f $@
#	cp $< $@
#
#$(WEBDIR)/%.txt: %.txt
#	rm -f $@
#	cp $< $@
#
#www: $(WEBDOCS:%=$(WEBDIR)/%) 
#	
#spotless: clean
#	-rm -f make-cs.tmp $(XSRCS)
#	-rm -f mf-unix.mak mf-msdos.mak makefile.new Makefile.bak mf-deps.mak
#	-rm -f expand.tmp readme.txt readme.html why.txt why.html
#	-rm -f conformance.html conformance.txt
#	-rm -f README WHY CONFORMANCE INSTALL *~
#	-rm -f msgscan lex.yy.c myscmsgs.new
#	-rm -rf dist-tmp dist-tmp.stamp dist.tar dist.shar.*
# YOW.
