/*
 * pf-add.c
 *
 * By Ross Ridge
 * Public Domain
 *
 * Members of the class sccs_pfile for adding an edit lock to the file.
 *
 */

#include "mysc.h"
#include "pfile.h"

#ifdef CONFIG_SCCS_IDS
static char const sccs_id[] = "@(#) MySC pf-add.c 1.4 98/01/06 08:24:26";
#endif

int 
sccs_pfile::add_lock(sid got, sid delta, 
		     sid_list &included, sid_list &excluded) {
	assert(mode == APPEND);

	struct edit_lock new_lock;

	new_lock.got = got;
	new_lock.delta = delta;
	new_lock.user = get_user_name();
	new_lock.date = sccs_date::now();
	new_lock.include = included;
	new_lock.exclude = excluded;
	new_lock.deleted = 0;

	edit_locks.add(new_lock);

	FILE *pf;
	if (edit_locks.length() == 0) {
		pf = fcreate(pname, CREATE_EXCLUSIVE | CREATE_BINARY);
		if (pf == NULL) {
			error(errno, msgptr(45, "%s: Can't create file."),
			      (char const *) pname);
			return -1;
		}
	} else {
		pf = fopen(pname, "ab");
		if (pf == NULL) {
			error(errno, msgptr(46, "%s: Can't open for append."),
			      (char const *) pname);
			return -1;
		}
	}

	if (write_edit_lock(pf, new_lock)
	    || fflush(pf) == EOF) {
		error(errno, msgptr(42, "%s: Write error."), 
		      (char const *) pname);
		fclose(pf);
		return -1;
	}
	fclose(pf);
	return 0;
}

/* Local variables: */
/* mode: c++ */
/* End: */
