/*
 * pf-del.c
 *
 * By Ross Ridge 
 * Public Domain
 *
 * Members of the class sccs_pfile used when removing an edit lock from
 * a p-file.
 *
 */

#include "mysc.h"
#include "pfile.h"

#ifdef CONFIG_SCCS_IDS
static char const sccs_id[] = "@(#) MySC pf-del.c 1.6 98/01/06 08:24:28";
#endif

/* enum */ sccs_pfile::find_status
sccs_pfile::find_sid(sid id) {

	rewind();

	char const *user = get_user_name();
	sccs_pfile &it = *this;
	int found = -1;

	while(next()) {
		if (strcmp(user, it->user) == 0
		    && (id == NULL || id == it->got || id == it->delta)) {
			if (found != -1) {
				return AMBIGUOUS;
			}
			found = pos;
		}
	}

	if (found == -1) {
		return NOT_FOUND;
	}

	pos = found;

	return FOUND;
}

int
sccs_pfile::update() {
	string qname = name.qfile();

	FILE *pf = fopen(qname, "wb");
	if (pf == NULL) {
		error(errno, msgptr(47, "%s: Can't create temporary file."),
		      (char const *) qname);
		return -1;
	}

        int count = 0;

	rewind();
	while(next()) {
		if (write_edit_lock(pf, *operator->())) {
			error(errno, msgptr(42, "%s: Write error."),
			      (char const *) qname);
			fclose(pf);
			return -1;
		}
		count++;
	}

	if (fclose(pf) == EOF) {
		error(errno, msgptr(42, "%s: Write error."),
		      (char const *) qname);
		return -1;
	}

#ifndef TESTING	

	if (remove(pname) != 0) {
		error(errno, msgptr(48, "%s: Can't remove file."),
		      (char const *) pname);
		return -1;
	}

	if (count == 0) {
		if (remove(qname) != 0) {
			error(errno,
			      msgptr(49, "%s: Can't remove temporary file."),
			      (char const *) pname);
			return -1;
		}
	} else {
		if (rename(qname, pname) != 0) {
			error(errno, msgptr(50, "%s: Can't rename file."),
			      (char const *) qname);
			return -1;
		}
	}
#endif

	return 0;
}

/* Local variables: */
/* mode: c++ */
/* End: */
