/*
 * sact.c
 *
 * By Ross Ridge
 * Public Domain
 *
 * Prints the current edit locks for an SCCS file. 
 *
 */

#include "mysc.h"
#include "version.h"
#include "fileiter.h"
#include "pfile.h"

char const main_sccs_id[] = "@(#) MySC sact.c 1.7 98/03/17 17:41:52";

void
usage() {
	fprintf(stderr, msgptr(83, "usage: %s [-V] file ...\n"), prg_name);
}

int
main(int argc, char **argv) {
	int return_status = 0;

	if (argc > 0) {
		set_prg_name(argv[0]);
	} else {
		set_prg_name("sact");
	}

	setlocale(LC_ALL, "");
	init_msgdb();

	if (argc > 1 && strcmp(argv[1], "-V") == 0) {
		version();
		argc--;
		argv++;
	}

	sccs_file_iterator iter(argc, argv);
	if (iter.length_zero()) {
		quit(-2, msgptr(16, "No SCCS file specified."));
	}

	for(; iter != sccs_file_iterator(); ++iter) {
		sccs_name &name = *iter;

		/*
		 * Check to see if there actually is a SCCS file.
		 */

		if (!name.valid()) {
			error(msgptr(20, "%s: Not an SCCS file."),
			      (char const *) name);
			return_status = 1;
			continue;
		}

		if (!is_readable(name)) {
			error(errno, msgptr(186, "%s: SCCS file doesn't exist."),
			      (char const *) name);
			return_status = 1;
			continue;
		}

		sccs_pfile pfile(name, sccs_pfile::READ);
		if (pfile.failed()) {
			return_status = 1;
			continue;
		}

		pfile.rewind();
		if (pfile.next()) {
			if (iter.length_many()) {
				if (printf("%s:\n", (char const *) name)
				    == EOF) {
					quit(errno,
					     msgptr(42, "%s: Write error."),
					     "-");
				}
			}
			do {
				if (pfile->got.print(stdout) == EOF
				    || putchar(' ') == EOF
				    || pfile->delta.print(stdout) == EOF
				    || putchar(' ') == EOF
				    || fputs(pfile->user, stdout) == EOF
				    || putchar(' ') == EOF
				    || pfile->date.print(stdout) == EOF
				    || putchar('\n') == EOF) {
					quit(errno,
					     msgptr(42, "%s: Write error."),
					     "-");
				}
			} while(pfile.next());
		}
	}

	return return_status;
}

/* Local variables: */
/* mode: c++ */
/* End: */
