/*
 * sf-write.c
 *
 * By Ross Ridge
 * Public Domain
 *
 * Members of the class sccs_file used adding a new delta to the SCCS
 * file.
 * 
 */

#include "mysc.h"
#include "sccsfile.h"

#ifdef CONFIG_SCCS_IDS
static char const sccs_id[] = "@(#) MySC sf-add.c 1.4 98/04/12 20:00:20";
#endif

/* Insert a delta at the start of the delta table. */

int
sccs_file::_delta_table::prepend(struct delta const &it) {
	int i;
	if (left == 0) {
		grow(len, 1);
	} else {
		for(i = len; i > 0; i--) {
			array[i] = array[i - 1];
		}
	}
	array[0] = it;
	len++;
	left--;

	return update_highest(it);
}


/* Starts an update of an SCCS file that includes a new entry to be
   prepended to delta table. */

FILE *
sccs_file::start_update(struct delta const &new_delta) {
	FILE *out = start_update();

	if (out == NULL) {
		return NULL;
	}

	if (write_delta(out, new_delta) == -1 
	    || write(out) == -1) {
		xfile_error(msgptr(111, "Write error."));
		fclose(out);
		return NULL;
	}
	return out;
}


/* Set the line counts in the prepended delta and then end the update. */

int
sccs_file::end_update(FILE *out, struct delta const &delta) {
	if (fflush(out) == EOF) {
		xfile_error(msgptr(111, "Write error."));
		fclose(out);
		return -1;
	}

	rewind(out);

	if (fprintf(out, "\001h-----\n\001s %05u/%05u/%05u",
		    delta.inserted, delta.deleted, delta.unchanged) == EOF) {
		xfile_error(msgptr(111, "Write error."));
		fclose(out);
		return -1;
	}

	if (end_update(out) == -1) {
		return -1;
	}

	return delta_table.prepend(delta);
}

/* Local variables: */
/* mode: c++ */
/* End: */
