/*
 * sf-rmdel.c
 *
 * By Ross Ridge
 * Public Domain
 *
 * Members of the class sccs_file used for marking a delta in the SCCS
 * files as removed.
 *
 */

#include "mysc.h"
#include "sccsfile.h"

#ifdef CONFIG_SCCS_IDS
static char const sccs_id[] = "@(#) MySC sf-rmdel.c 1.4 98/01/06 22:21:04";
#endif

static int
is_seqlist_member(seq_no seq, list<seq_no> const &seq_list) {
	int i;
	int len = seq_list.length();
	for(i = 0; i < len; i++) {
		if (seq == seq_list[i]) {
			return 1;
		}
	}
	return 0;
}

int
sccs_file::rmdel(sid id) {
	struct delta *delta = (struct delta *) delta_table.find(id);
	if (delta == NULL) {
		error(msgptr(182, "%s: Requested SID not found."),
		      (char const *) name);
		return -1;
	}
	seq_no seq = delta->seq;

	delta_iterator iter(delta_table);
	while(iter.next()) {
		if (iter->prev_seq == seq) {
			error(msgptr(161,
				     "%s: Requested SID has a successor."),
			      (char const *) name);
			return -1;
		}
		if (is_seqlist_member(seq, iter->included)
		    || is_seqlist_member(seq, iter->excluded)
		    || is_seqlist_member(seq, iter->ignored)) {
			error(msgptr(162, "%s: Requested SID is used"
				     " in another delta."),
			      (char const *) name);
			return -1;
		}
	}

	delta->type = 'R';
	
	FILE *out = start_update();
	if (out == NULL) {
		return -1;
	}

	if (write(out) == -1) {
		xfile_error(msgptr(111, "Write error."));
		fclose(out);
		return -1;
	}

	enum { COPY, DELETE, INSERT} state = COPY;
	int c = read_line();
	while(c != -1 && c != -2) {
		if (c != 0) {
			if (check_arg() == -1) {
				fclose(out);
				return -1;
			}
			int err = 0;
			if (strict_atous(linebuf + 3, &err) == seq && !err) {
				if (state == COPY && c == 'I') {
					state = INSERT;
				} else if (state == COPY && c == 'D') {
					state = DELETE;
				} else if (state != COPY && c == 'E') {
					state = COPY;
				} else {
					corrupt(msgptr(136, "Unexpected"
						       " control line"));
					fclose(out);
					return -1;
				}
				c = read_line();
				continue;
			} else if (err) {
				return -1;
			}

			if (state == INSERT) {
				corrupt(msgptr(163, "Non-terminal delta!?!"));
				fclose(out);
				return -1;
			}
		}
		if (state != INSERT) {
			if (fputs(linebuf, out) == EOF
			    || putc('\n', out) == EOF) {
				xfile_error(msgptr(111, "Write error."));
				fclose(out);
				return -1;
			}
		}
		c = read_line();
	}

	if (c == -2) {
		fclose(out);
		return -1;
	}

	if (state != COPY) {
		corrupt(msgptr(164, "Unexpected EOF"));
		fclose(out);
		return -1;
	}

	return end_update(out);
}
	
/* Local variables: */
/* mode: c++ */
/* End: */
